@@ -41,8 +41,6 @@
 
 #define KWALLET_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KWALLET_NO_DEPRECATED) && !defined(KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KWALLET_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWALLET_NO_DEPRECATED
-#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KWALLET_NO_DEPRECATED_WARNINGS
 #  define KWALLET_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWALLET_DEPRECATED_WARNINGS_SINCE KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KWALLET_DEPRECATED
-#  define KWALLET_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KWALLET_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KWALLET_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
